Struct ZwpTabletV2
pub struct ZwpTabletV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
graphics tablet device
The zwp_tablet_v2 interface represents one graphics tablet device. The tablet interface itself does not generate events; all events are generated by zwp_tablet_tool_v2 objects when in proximity above a tablet.
A tablet has a number of static characteristics, e.g. device name and pid/vid. These capabilities are sent in an event sequence after the zwp_tablet_seat_v2.tablet_added event. This initial event sequence is terminated by a zwp_tablet_v2.done event.
See also the Event enum for this interface.
Implementations
impl ZwpTabletV2
impl ZwpTabletV2
pub fn destroy(&self)
pub fn destroy(&self)
destroy the tablet object
This destroys the client’s resource for this tablet object.